@@ -3,6 +3,7 @@ use std::{path::PathBuf, sync::LazyLock};
 use color_eyre::eyre::Result;
 use directories::{BaseDirs, ProjectDirs};
 use human_panic::Metadata;
+use ratatui::layout::Rect;
 use tracing::error;
 use tracing_error::ErrorLayer;
 use tracing_subscriber::{
@@ -181,3 +182,7 @@ Config directory: {config_dir_path}
 Data directory: {data_dir_path}"
     )
 }
+
+pub fn is_in_area(x: u16, y: u16, area: Rect) -> bool {
+    x >= area.x && x < area.x + area.width && y >= area.y && y < area.y + area.height
+}
